@@ -19,25 +19,27 @@
 #     along with this program.  If not, see <http://www.gnu.org/licenses/>
 
 import os
-import subprocess
-import numpy as np
 import re
+import subprocess
 from random import random
 
+import numpy as np
+
 # initial condition regex. The syntax differs depending on scalar or array.
 # if scalar inits, we have 'init v=*' or 'v(0)=*'
 # if array init, we have 'init v[0..10]=*' or 'v[0..10](0)=*'
 
 # scalar inits
-init_re_sc1 = '^ *(init) (.+)$'
-init_re_sc2 = '^ *(.+ *\( *0 *\) *.+)$'
-init_re_ar1 = '^ *(init) (.+ *\[[0-9]+\.\.[0-9]+\] *.+)$'
+init_re_sc1 = "^ *(init) (.+)$"
+init_re_sc2 = "^ *(.+ *\( *0 *\) *.+)$"
+init_re_ar1 = "^ *(init) (.+ *\[[0-9]+\.\.[0-9]+\] *.+)$"
 # init_re_ar1b = '^ *(init) (.+ *\[[0-9]+\.\.[0-9]+\] *.+)$'
-init_re_ar2 = '^ *(.+ *\[[0-9]+\.\.[0-9]+\] *\( *0 *\) *.+)$'
+init_re_ar2 = "^ *(.+ *\[[0-9]+\.\.[0-9]+\] *\( *0 *\) *.+)$"
 
 
 # array inits coming soon...
 
+
 def file_to_lines(filepath):
     with open(filepath, "r") as f:
         content = f.readlines()
@@ -51,7 +53,7 @@ def search_state_vars_in_srclines(srclines):
     return:
     the list of names of found state variables
     """
-    der = [];
+    der = []
     aux = []
 
     # find scalar defined vars
@@ -59,13 +61,18 @@ def search_state_vars_in_srclines(srclines):
         # print line
 
         # find scalar vars
-        so_sc = re.search('^ *d([a-zA-Z0-9_]+)/dt[ \t]*=|^ *([a-zA-Z0-9_]+)\'[ \t]*=|^ *aux +([a-zA-Z0-9_]+) *=', line,
-                          flags=re.IGNORECASE)
+        so_sc = re.search(
+            "^ *d([a-zA-Z0-9_]+)/dt[ \t]*=|^ *([a-zA-Z0-9_]+)'[ \t]*=|^ *aux +([a-zA-Z0-9_]+) *=",
+            line,
+            flags=re.IGNORECASE,
+        )
 
         # find array vars
         so_ar = re.search(
-            '^ *([a-zA-Z0-9_]+)(\[[0-9]+\.\.[0-9]+\])\'[ \t]*=|^ *aux +([a-zA-Z0-9_]+)(\[[0-9]+\.\.[0-9]+\]) *=', line,
-            flags=re.IGNORECASE)
+            "^ *([a-zA-Z0-9_]+)(\[[0-9]+\.\.[0-9]+\])'[ \t]*=|^ *aux +([a-zA-Z0-9_]+)(\[[0-9]+\.\.[0-9]+\]) *=",
+            line,
+            flags=re.IGNORECASE,
+        )
 
         if so_sc is not None:
 
@@ -84,7 +91,7 @@ def search_state_vars_in_srclines(srclines):
                     indices = so_ar.group(2)[1:-1]
 
                     # get lower and upper numbers of list
-                    indices = indices.split('..')
+                    indices = indices.split("..")
 
                     low_idx = int(indices[0])
                     hi_idx = int(indices[-1])
@@ -103,7 +110,7 @@ def search_state_vars_in_srclines(srclines):
 
 
 def read_numerics_settings(srclines, num_names=None):
-    """ srclines - an ODE-file content in the list of strings,
+    """srclines - an ODE-file content in the list of strings,
     if num_names is None all non-default numerical parameters will be read
     num_names - the list of numerical options
 
@@ -112,9 +119,16 @@ def read_numerics_settings(srclines, num_names=None):
     """
 
     vars_list = []
-    i_num_lines = np.nonzero([re.search('^ *(@) (.+)$', line, flags=re.IGNORECASE) is not None for line in srclines])[0]
+    i_num_lines = np.nonzero(
+        [
+            re.search("^ *(@) (.+)$", line, flags=re.IGNORECASE) is not None
+            for line in srclines
+        ]
+    )[0]
     for i in i_num_lines:
-        vars_list += re.findall('([a-z0-9_]+) *= *([0-9\.e\-\+]+)', srclines[i].lower(), flags=re.IGNORECASE)
+        vars_list += re.findall(
+            "([a-z0-9_]+) *= *([0-9\.e\-\+]+)", srclines[i].lower(), flags=re.IGNORECASE
+        )
     d = dict(vars_list)
     if num_names is None:
         return d
@@ -135,7 +149,7 @@ def read_numerics_settings_from_file(filepath, num_names=None):
 
 
 def read_pars_values(srclines, pars_names=None):
-    """ srclines - an ODE-file content in the list of strings,
+    """srclines - an ODE-file content in the list of strings,
     if pars_names is None all parameters will be read
     pars_names - the list of parameters names
 
@@ -144,10 +158,18 @@ def read_pars_values(srclines, pars_names=None):
     """
     vars_list = []
     i_par_lines = np.nonzero(
-        [re.search('^ *(parameters|par|param|params|p) (.+)$', line, flags=re.IGNORECASE) is not None for line in
-         srclines])[0]
+        [
+            re.search(
+                "^ *(parameters|par|param|params|p) (.+)$", line, flags=re.IGNORECASE
+            )
+            is not None
+            for line in srclines
+        ]
+    )[0]
     for i in i_par_lines:
-        vars_list += re.findall('([a-z0-9_]+) *= *([0-9\.e\-\+]+)', srclines[i].lower(), flags=re.IGNORECASE)
+        vars_list += re.findall(
+            "([a-z0-9_]+) *= *([0-9\.e\-\+]+)", srclines[i].lower(), flags=re.IGNORECASE
+        )
     d = dict(vars_list)
     if pars_names is None:
         return d
@@ -174,8 +196,10 @@ def change_parameters_in_ode_and_save(srclines, parameters, newfilepath):
     newfilepath - path to a new ODE file with modified parameters
     """
     # Max : replaced iteritems() by items() for python 3
-    lparameters = {pn.lower(): (lambda x: repr(x) if not isinstance(x, str) else x)(pv) for pn, pv in
-                   parameters.items()}
+    lparameters = {
+        pn.lower(): (lambda x: repr(x) if not isinstance(x, str) else x)(pv)
+        for pn, pv in parameters.items()
+    }
     pnames = lparameters.keys()
 
     def repl_in_par(matchobj):
@@ -186,18 +210,29 @@ def change_parameters_in_ode_and_save(srclines, parameters, newfilepath):
             return matchobj.group(0)
 
     i_par_lines = np.nonzero(
-        [re.search('^ *(parameters|par|param|params|p) (.+)$', line, flags=re.IGNORECASE) is not None for line in
-         srclines])[0]
+        [
+            re.search(
+                "^ *(parameters|par|param|params|p) (.+)$", line, flags=re.IGNORECASE
+            )
+            is not None
+            for line in srclines
+        ]
+    )[0]
     nsrclines = srclines[:]
     for i in i_par_lines:
-        nsrclines[i] = re.sub('([a-z0-9_]+)( *= *)([0-9\.e\-\+]+)', repl_in_par, nsrclines[i], flags=re.IGNORECASE)
-    nsrc = ''.join(nsrclines)
-    with open(newfilepath, 'w') as f:
+        nsrclines[i] = re.sub(
+            "([a-z0-9_]+)( *= *)([0-9\.e\-\+]+)",
+            repl_in_par,
+            nsrclines[i],
+            flags=re.IGNORECASE,
+        )
+    nsrc = "".join(nsrclines)
+    with open(newfilepath, "w") as f:
         f.write(nsrc)
 
 
 def read_init_values(srclines, init_names=None):
-    """ srclines - an ODE-file content in the list of strings,
+    """srclines - an ODE-file content in the list of strings,
     if init_names is None all parameters will be read
     init_names - the list of parameters names
 
@@ -205,25 +240,47 @@ def read_init_values(srclines, init_names=None):
     the dict of parameters, where keys=pars_names, values are parsed from srclines
     """
 
-    vars_list_sc1 = [];
-    vars_list_sc2 = [];
-    vars_list_ar1 = [];
-    vars_list_ar2 = [];
+    vars_list_sc1 = []
+    vars_list_sc2 = []
+    vars_list_ar1 = []
+    vars_list_ar2 = []
     vars_list_ar3 = []
-    i_init_lines = np.nonzero([re.search(init_re_sc1 + '|' + \
-                                         init_re_sc2 + '|' + \
-                                         init_re_ar1 + '|' + \
-                                         init_re_ar2, line, flags=re.IGNORECASE) is not None for line in srclines])[0]
+    i_init_lines = np.nonzero(
+        [
+            re.search(
+                init_re_sc1 + "|" + init_re_sc2 + "|" + init_re_ar1 + "|" + init_re_ar2,
+                line,
+                flags=re.IGNORECASE,
+            )
+            is not None
+            for line in srclines
+        ]
+    )[0]
 
     for i in i_init_lines:
-        vars_list_sc1 += re.findall('([a-z0-9_]+) *= *([0-9\.e\-\+]+)', srclines[i].lower(), flags=re.IGNORECASE)
-        vars_list_sc2 += re.findall('([a-z0-9_]+ *\( *0 *\)) *= *([0-9\.e\-\+]+)', srclines[i].lower(),
-                                    flags=re.IGNORECASE)
-        vars_list_ar1 += re.findall('([a-z0-9_]+\[[0-9]+\.\.[0-9]+\] *\( *0 *\)) *= *([0-9\.e\-\+]+)',
-                                    srclines[i].lower(), flags=re.IGNORECASE)
-        vars_list_ar2 += re.findall('([a-z0-9_]+\[[0-9]+\.\.[0-9]+\]) *= *([0-9\.e\-\+]+)', srclines[i].lower(),
-                                    flags=re.IGNORECASE)
-        vars_list_ar3 += re.findall('([a-z0-9_]+\[j\]) *= *([0-9\.e\-\+]+)', srclines[i].lower(), flags=re.IGNORECASE)
+        vars_list_sc1 += re.findall(
+            "([a-z0-9_]+) *= *([0-9\.e\-\+]+)", srclines[i].lower(), flags=re.IGNORECASE
+        )
+        vars_list_sc2 += re.findall(
+            "([a-z0-9_]+ *\( *0 *\)) *= *([0-9\.e\-\+]+)",
+            srclines[i].lower(),
+            flags=re.IGNORECASE,
+        )
+        vars_list_ar1 += re.findall(
+            "([a-z0-9_]+\[[0-9]+\.\.[0-9]+\] *\( *0 *\)) *= *([0-9\.e\-\+]+)",
+            srclines[i].lower(),
+            flags=re.IGNORECASE,
+        )
+        vars_list_ar2 += re.findall(
+            "([a-z0-9_]+\[[0-9]+\.\.[0-9]+\]) *= *([0-9\.e\-\+]+)",
+            srclines[i].lower(),
+            flags=re.IGNORECASE,
+        )
+        vars_list_ar3 += re.findall(
+            "([a-z0-9_]+\[j\]) *= *([0-9\.e\-\+]+)",
+            srclines[i].lower(),
+            flags=re.IGNORECASE,
+        )
 
     # remove '(0)' from vars_list_sc2
     for i in range(len(vars_list_sc2)):
@@ -243,7 +300,9 @@ def read_init_values(srclines, init_names=None):
 
     # implement remove '(0)' from vars_list_ar2
     # print vars_list_sc1,vars_list_ar2
-    vars_list = vars_list_sc1 + vars_list_sc2 + vars_list_ar1 + vars_list_ar2 + vars_list_ar3
+    vars_list = (
+        vars_list_sc1 + vars_list_sc2 + vars_list_ar1 + vars_list_ar2 + vars_list_ar3
+    )
     d = dict(vars_list)
     if init_names is None:
         return d
@@ -269,9 +328,12 @@ def change_inits_in_ode_and_save(srclines, inits, newfilepath):
     inits - the dict of inits to set up new values, all keys in low register!
     newfilepath - path to a new ODE file with modified inits
     """
-    
+
     # Max : replaced iteritems() by items() for python 3
-    linits = {pn.lower(): (lambda x: repr(x) if not isinstance(x, str) else x)(pv) for pn, pv in inits.items()}
+    linits = {
+        pn.lower(): (lambda x: repr(x) if not isinstance(x, str) else x)(pv)
+        for pn, pv in inits.items()
+    }
     pnames = linits.keys()
 
     def repl_in_par(matchobj):
@@ -284,7 +346,12 @@ def change_inits_in_ode_and_save(srclines, inits, newfilepath):
         if matchobj.group(2) != None:
 
             if mog in pnames:
-                out = matchobj.group(1) + matchobj.group(2) + matchobj.group(3) + linits[mog]
+                out = (
+                    matchobj.group(1)
+                    + matchobj.group(2)
+                    + matchobj.group(3)
+                    + linits[mog]
+                )
                 out = out.replace(" ", "")
                 return out
             else:
@@ -314,7 +381,7 @@ def change_inits_in_ode_and_save(srclines, inits, newfilepath):
 
         # get idx limits
         idx = matchobj.group(2)
-        idx = idx.split('..')
+        idx = idx.split("..")
         low_idx = int(idx[0])
         hi_idx = int(idx[-1])
         idxrange = np.arange(low_idx, hi_idx + 1, 1)
@@ -330,18 +397,26 @@ def change_inits_in_ode_and_save(srclines, inits, newfilepath):
                 # this is where we convert from v[0..2]=1 syntax to v0=1,v1=1,v2=1 syntax.
                 # print mog
                 listval = linits[mog][1:-1]
-                listval = listval.split(',')
+                listval = listval.split(",")
 
                 # print listval
 
                 if len(listval) != len(idxrange):
                     raise ValueError(
-                        'make sure ode array numbers coincide with the number of initial conditions. e.g. if v[1..3](0)=1, v0(0)=2, and you want to change the inits to v0=1,v1=4,v2=5,v3=6, then use inits {\'v0\':1,\'v\':[4,5,6]}')
+                        "make sure ode array numbers coincide with the number of initial conditions. e.g. if v[1..3](0)=1, v0(0)=2, and you want to change the inits to v0=1,v1=4,v2=5,v3=6, then use inits {'v0':1,'v':[4,5,6]}"
+                    )
 
-                inits_new = ''
+                inits_new = ""
                 for i in range(len(idxrange)):
                     # print idxrange[i]
-                    inits_new += matchobj.group(1) + str(idxrange[i]) + matchobj.group(3) + '=' + listval[i] + '\n'
+                    inits_new += (
+                        matchobj.group(1)
+                        + str(idxrange[i])
+                        + matchobj.group(3)
+                        + "="
+                        + listval[i]
+                        + "\n"
+                    )
 
                 # trim trailing comma, force newline
                 inits_new = inits_new[:-1]
@@ -362,15 +437,17 @@ def change_inits_in_ode_and_save(srclines, inits, newfilepath):
 
                 # remove list index brackets '[0,1,2]' -> '0,1,2'
                 listval = linits[mog][1:-1]
-                listval = listval.split(',')
+                listval = listval.split(",")
 
-                inits_new = ''
+                inits_new = ""
 
                 print
                 mog, pnames, idxrange
                 for i in range(len(idxrange)):
                     # print idxrange[i]
-                    inits_new += matchobj.group(1) + str(idxrange[i]) + '=' + listval[i] + ','
+                    inits_new += (
+                        matchobj.group(1) + str(idxrange[i]) + "=" + listval[i] + ","
+                    )
 
                 # trim trailing comma
                 inits_new = inits_new[:-1]
@@ -382,17 +459,31 @@ def change_inits_in_ode_and_save(srclines, inits, newfilepath):
                 return matchobj.group(0)
 
     # get lines of inits
-    i_par_lines = np.nonzero([re.search(init_re_sc1 + '|' + \
-                                        init_re_sc2, line, flags=re.IGNORECASE) is not None for line in srclines])[0]
+    i_par_lines = np.nonzero(
+        [
+            re.search(init_re_sc1 + "|" + init_re_sc2, line, flags=re.IGNORECASE)
+            is not None
+            for line in srclines
+        ]
+    )[0]
 
     # get lines of array inits
-    i_ar_lines = np.nonzero([re.search(init_re_ar1 + '|' + \
-                                       init_re_ar2, line, flags=re.IGNORECASE) is not None for line in srclines])[0]
+    i_ar_lines = np.nonzero(
+        [
+            re.search(init_re_ar1 + "|" + init_re_ar2, line, flags=re.IGNORECASE)
+            is not None
+            for line in srclines
+        ]
+    )[0]
     # print i_ar_lines
 
     # get line of 'done' flag. empty string if it does not exist.
-    i_d_line = np.nonzero([re.search('^ *(d)|^ *(done)', line, flags=re.IGNORECASE) is not None for line in srclines])[
-        0]
+    i_d_line = np.nonzero(
+        [
+            re.search("^ *(d)|^ *(done)", line, flags=re.IGNORECASE) is not None
+            for line in srclines
+        ]
+    )[0]
 
     # if the done flag position is empty, return -1
     # else return the position number.
@@ -402,14 +493,14 @@ def change_inits_in_ode_and_save(srclines, inits, newfilepath):
         i_d_line = i_d_line[0]
 
     # mark which inits exist and which do not.
-    dnelist = 'init '
+    dnelist = "init "
     idx = 0
 
     # create list for deletion of state variable keys that do not exist
     delete_keys = []
 
     # cram all inits into one line, to make it easy to check if state variable exists
-    combinedlist = ''
+    combinedlist = ""
 
     for i in range(len(i_par_lines)):
         combinedlist += srclines[i_par_lines[i]]
@@ -424,8 +515,10 @@ def change_inits_in_ode_and_save(srclines, inits, newfilepath):
 
             vn = search_state_vars_in_srclines(srclines)
 
-            if k in vn:  # if state variable exists, take note that the init was not defined in the ode script
-                dnelist += k + '=' + str(inits[k])
+            if (
+                k in vn
+            ):  # if state variable exists, take note that the init was not defined in the ode script
+                dnelist += k + "=" + str(inits[k])
             else:
                 # if the state variable does not exist in the ODE file, ignore.
                 delete_keys.append(k)
@@ -435,25 +528,33 @@ def change_inits_in_ode_and_save(srclines, inits, newfilepath):
         del inits[key]
 
     # if there exist user-defined inits (not initialized in the script) that are existing state variables ...
-    if dnelist != 'init ':
+    if dnelist != "init ":
         # if new inits defined, move done flag to end
-        srclines[i_d_line] = ''
-        dnelist += '\n'
+        srclines[i_d_line] = ""
+        dnelist += "\n"
         srclines.append(dnelist)  # add the new inits
-        srclines.append('d')
+        srclines.append("d")
     # print srclines
 
     nsrclines = srclines[:]
     for i in i_par_lines:
-        nsrclines[i] = re.sub('([a-z0-9_]+)( *\( *0 *\) *)?( *= *)([0-9\.e\-\+]+)', repl_in_par, nsrclines[i],
-                              flags=re.IGNORECASE)
+        nsrclines[i] = re.sub(
+            "([a-z0-9_]+)( *\( *0 *\) *)?( *= *)([0-9\.e\-\+]+)",
+            repl_in_par,
+            nsrclines[i],
+            flags=re.IGNORECASE,
+        )
 
     for i in i_ar_lines:
-        nsrclines[i] = re.sub('([a-z0-9_]+)\[([0-9]+..[0-9]+)\]( *\( *0 *\) *)?( *= *)([0-9\.e\-\+]+)', repl_in_ar,
-                              nsrclines[i], flags=re.IGNORECASE)
+        nsrclines[i] = re.sub(
+            "([a-z0-9_]+)\[([0-9]+..[0-9]+)\]( *\( *0 *\) *)?( *= *)([0-9\.e\-\+]+)",
+            repl_in_ar,
+            nsrclines[i],
+            flags=re.IGNORECASE,
+        )
 
-    nsrc = ''.join(nsrclines)
-    with open(newfilepath, 'w') as f:
+    nsrc = "".join(nsrclines)
+    with open(newfilepath, "w") as f:
         f.write(nsrc)
 
 
@@ -464,14 +565,29 @@ def check_if_in_ode(srclines, inits):
     check whether a set of inits are listed in an ODE
     return {dictonary of existing guys}, {dictionary of nonexisting guys}
     """
-    i_par_lines = np.nonzero([re.search(init_re_sc1 + '|' + \
-                                        init_re_sc2 + '|' + \
-                                        init_re_ar1 + '|' + \
-                                        init_re_ar2, line, flags=re.IGNORECASE) is not None for line in srclines])[0]
+    i_par_lines = np.nonzero(
+        [
+            re.search(
+                init_re_sc1 + "|" + init_re_sc2 + "|" + init_re_ar1 + "|" + init_re_ar2,
+                line,
+                flags=re.IGNORECASE,
+            )
+            is not None
+            for line in srclines
+        ]
+    )[0]
     return i_par_lines
 
 
-def xpprun(filepath, version=8, xppname='xppaut', postfix='_tmp', parameters=None, inits=None, clean_after=False):
+def xpprun(
+    filepath,
+    version=8,
+    xppname="xppaut",
+    postfix="_tmp",
+    parameters=None,
+    inits=None,
+    clean_after=False,
+):
     """
     A simple interface to xppaut. It runs xpp in a silent mode 'xpp some_ode_file.ode -silent'
     and analyses the result of computation, a file produced by xpp (output.dat by default).
@@ -507,16 +623,16 @@ def xpprun(filepath, version=8, xppname='xppaut', postfix='_tmp', parameters=Non
     path, filename = os.path.split(filepath)
     name, ext = os.path.splitext(filename)
     wd = os.getcwd()
-    rndid = '';
-    rndid2 = '';
-    newfilepath = ''
+    rndid = ""
+    rndid2 = ""
+    newfilepath = ""
 
     if version < 8:
         # legacy code. Adds compatibility to older xpp versions that do not have command line inputs
         # forwards compatible for now
 
         if (parameters is not None) or (inits is not None):
-            rndid = '_rndid' + str(int(random() * 1e15))
+            rndid = "_rndid" + str(int(random() * 1e15))
             filename = name + postfix + rndid + ext  # change to new file
             newfilepath = os.path.join(path, filename)
             fullfilename = os.path.join(path, filename)
@@ -527,17 +643,20 @@ def xpprun(filepath, version=8, xppname='xppaut', postfix='_tmp', parameters=Non
         else:
             fullfilename = os.path.join(path, filename)
 
-        if path != '':
+        if path != "":
             os.chdir(path)
-        outputfile = 'output%s.dat' % (rndid + rndid2)
+        outputfile = "output%s.dat" % (rndid + rndid2)
         outputfilepath = os.path.join(path, outputfile)
 
         try:
-            res = subprocess.check_output("%s %s -silent -outfile %s" % (xppname, fullfilename, outputfilepath),
-                                          stderr=subprocess.STDOUT, shell=True)
+            res = subprocess.check_output(
+                "%s %s -silent -outfile %s" % (xppname, fullfilename, outputfilepath),
+                stderr=subprocess.STDOUT,
+                shell=True,
+            )
             os.chdir(wd)
 
-            out = np.genfromtxt(outputfilepath, delimiter=' ')
+            out = np.genfromtxt(outputfilepath, delimiter=" ")
 
             vn = search_state_vars_in_srclines(srclines)
             ret = out, vn
@@ -546,25 +665,23 @@ def xpprun(filepath, version=8, xppname='xppaut', postfix='_tmp', parameters=Non
 
             ret = None
 
-
-
     else:
         # if xpp version >= 8, run using command line inputs.
 
         # clean inputs into cli compatible format
-        inputstr = ''
+        inputstr = ""
 
         if (parameters is not None) and (parameters != {}):
             # for each parameter, append to string
             for opt in parameters:
-                inputstr += opt + '=' + str(parameters[opt]) + ';'
+                inputstr += opt + "=" + str(parameters[opt]) + ";"
 
         # remove trailing semicolon
         inputstr = inputstr[:-1]
 
         if (inits is not None) and (inits != {}):
             # for each input, append to string
-            rndid = '_rndid' + str(int(random() * 1e15))
+            rndid = "_rndid" + str(int(random() * 1e15))
             filename = name + postfix + rndid + ext  # change to new file
             newfilepath = os.path.join(path, filename)
             fullfilename = os.path.join(path, filename)
@@ -572,34 +689,35 @@ def xpprun(filepath, version=8, xppname='xppaut', postfix='_tmp', parameters=Non
         else:
             fullfilename = os.path.join(path, filename)
 
-        outputfile = 'output.dat'
+        outputfile = "output.dat"
         outputfilepath = os.path.join(path, outputfile)
 
         try:
 
             res = subprocess.check_output(
-                "%s %s -silent -with '%s' -runnow -outfile %s" % (xppname, fullfilename, inputstr, outputfilepath),
-                stderr=subprocess.STDOUT, shell=True)
+                "%s %s -silent -with '%s' -runnow -outfile %s"
+                % (xppname, fullfilename, inputstr, outputfilepath),
+                stderr=subprocess.STDOUT,
+                shell=True,
+            )
 
             os.chdir(wd)
 
-            out = np.genfromtxt(outputfilepath, delimiter=' ')
+            out = np.genfromtxt(outputfilepath, delimiter=" ")
 
             vn = search_state_vars_in_srclines(srclines)
 
             ret = out, vn
 
-
-
         except:
             print
-            'xpp was not called properly. check that xpp is installed and its alias.'
+            "xpp was not called properly. check that xpp is installed and its alias."
             ret = None
 
     if clean_after:
         if os.path.isfile(outputfilepath):
             os.remove(outputfilepath)
-        if newfilepath != '':
+        if newfilepath != "":
             os.remove(newfilepath)
 
     return ret
